==> xdelta3-gui_0.23.10.02.tar.xz: BUILD/translations/xdelta3-gui_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="27"/>
        <location filename="../mainwindow.ui" line="39"/>
        <source>Create delta</source>
        <extracomment>meaning to create a delta file that bridges between the source and target file
----------
start process</extracomment>
        <translation>Criar um arquivo delta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="30"/>
        <source>Create a binary difference between two files</source>
        <extracomment>meaning to create a delta file that bridges between the source and target file</extracomment>
        <translation>Criar uma diferença binária entre dois arquivos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="49"/>
        <source>Options</source>
        <extracomment>program options</extracomment>
        <translation>Opções</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="95"/>
        <source>Higher number = better compression ratio, but takes more time to finish</source>
        <translation>O número maior corresponde a melhor taxa de compactação, contudo, demora mais para terminar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="98"/>
        <source>Compression level</source>
        <extracomment>level of compression the delta file will use</extracomment>
        <translation>Nível de compressão</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="118"/>
        <source>More compression using various compression algorithms</source>
        <translation>Mais compactação utilizando vários tipos de algoritmos de compactação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="121"/>
        <source>Secondary compression</source>
        <extracomment>an extra layer of compression</extracomment>
        <translation>Compressão secundária</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="131"/>
        <location filename="../mainwindow.ui" line="241"/>
        <source>File selection</source>
        <extracomment>area for selecting input and output files</extracomment>
        <translation>Selecionar o arquivo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="143"/>
        <source>select target (new) file</source>
        <extracomment>select the new file from which to create a delta between it and the source.</extracomment>
        <translation>selecionar o novo arquivo de destino</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <source>Target file</source>
        <translation>Arquivo de destino</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="167"/>
        <source>Source file</source>
        <translation>Arquivo de origem</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="174"/>
        <source>Delta file name</source>
        <translation>Nome do arquivo delta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <source>Select source file...</source>
        <extracomment>starts a file chooser to select a file</extracomment>
        <translation>Selecionar o arquivo de origem...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="194"/>
        <source>select source (old) file</source>
        <extracomment>select the original or source file</extracomment>
        <translation>selecionar o arquivo antigo de origem</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="201"/>
        <source>Select target file...</source>
        <extracomment>starts a file chooser to select a file</extracomment>
        <translation>Selecionar o destino do arquivo...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="208"/>
        <source>Change location...</source>
        <extracomment>starts a file chooser to select destination for output delta file</extracomment>
        <translation>Alterar a localização...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="232"/>
        <location filename="../mainwindow.ui" line="332"/>
        <source>Apply delta</source>
        <extracomment>meaning to apply a delta file to a input file to create a new output file
----------
start the process</extracomment>
        <translation>Aplicar o delta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="235"/>
        <source>Create a new file applying a delta (difference) file to an original file</source>
        <extracomment>meaning to apply a delta file to a input file to create a new output file</extracomment>
        <translation>Criar um novo arquivo a partir de um arquivo delta (da diferença ou da variação) de um arquivo original</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="247"/>
        <source>Input file</source>
        <extracomment>a file to start with as the source or input</extracomment>
        <translation>Arquivo de entrada</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="254"/>
        <source>select input file</source>
        <extracomment>select the input or older file</extracomment>
        <translation>selecionar o arquivo de entrada</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="261"/>
        <source>Select input file...</source>
        <extracomment>starts a file chooser to select a file</extracomment>
        <translation>Selecionar o arquivo de entrada...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="268"/>
        <source>Delta file</source>
        <extracomment>the delta or diff file between the input and the output</extracomment>
        <translation>Arquivo delta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="275"/>
        <source>select delta</source>
        <extracomment>select the delta or patch file</extracomment>
        <translation>selecionar o arquivo delta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="282"/>
        <source>Select delta...</source>
        <extracomment>starts a file chooser to select a file</extracomment>
        <translation>Selecionar o arquivo delta...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <source>Output file</source>
        <extracomment>the final patched output file</extracomment>
        <translation>Arquivo de saída</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="299"/>
        <source>use default, or set up a custom name</source>
        <extracomment>create the new file name</extracomment>
        <translation>utilizar o nome padrão ou definir um nome personalizado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="306"/>
        <source>Change location..</source>
        <extracomment>starts a file chooser to select destination for output file</extracomment>
        <translation>Alterar a localização...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="98"/>
        <source>ISO Files (*.iso);;All Files (*)</source>
        <comment>kinds of files to choose</comment>
        <translation>Arquivos ISO (*.iso);; Todos os Formatos de Arquivos (*)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="99"/>
        <source>ISO Files (*.xdelta3);;All Files (*)</source>
        <comment>kinds of files to choose</comment>
        <translation>Arquivos ISO (*.xdelta3);; Todos os Formatos de Arquivos (*)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="101"/>
        <source>Select file</source>
        <comment>choose a file</comment>
        <translation>Selecionar o arquivo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="120"/>
        <source>Select directory to place the file in</source>
        <comment>select a target directory</comment>
        <translation>Selecionar o diretório para armazenar o arquivo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="132"/>
        <source>Path not found</source>
        <comment>warning about not finding the target directory</comment>
        <translation>O caminho não foi encontrado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="132"/>
        <source>Please select directory again.</source>
        <comment>message to try again</comment>
        <translation>Por favor, selecione novamente o diretório.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="141"/>
        <location filename="../mainwindow.cpp" line="170"/>
        <location filename="../mainwindow.cpp" line="181"/>
        <location filename="../mainwindow.cpp" line="228"/>
        <source>Error</source>
        <translation>Ocorreu um erro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="141"/>
        <source>Please enter a name for the output file.</source>
        <translation>Por favor, insira um nome para o arquivo de saída.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="149"/>
        <source>File exists</source>
        <translation>O arquivo existe</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="149"/>
        <source>Output file exists, do you want to overwrite?</source>
        <comment>warning about overwritting an existing file</comment>
        <translation>O arquivo de saída já existe, você quer substituí-lo?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="165"/>
        <source>Success</source>
        <comment>information that file was successfully written</comment>
        <translation>O processo foi concluído com sucesso.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="166"/>
        <source>File was successfuly written to &apos;%1&apos; directory.</source>
        <comment>information that file was successfully written</comment>
        <translation>O arquivo foi gravado com sucesso no diretório ‘%1’.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="167"/>
        <source>Took %1 to patch the file.</source>
        <comment>elapsed time, leave %1 untranslated</comment>
        <translation>Demorou %1 para corrigir o arquivo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="170"/>
        <source>Error: Could not write the file.</source>
        <comment>information that there was an error creating the file</comment>
        <translation>Ocorreu um Erro: Não foi possível gravar o arquivo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="181"/>
        <source>Please enter a name for the delta file.</source>
        <comment>name of delta file being created</comment>
        <translation>Por favor, insira um nome para o arquivo delta.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="194"/>
        <source>File not found</source>
        <comment>warning about file not found</comment>
        <translation>O arquivo não foi encontrado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="195"/>
        <source>File &apos;%1&apos; found or not a file, please double-check the input.</source>
        <comment>warning about file not found</comment>
        <translation>O arquivo ‘%1’ que foi encontrado não é um arquivo. Por favor, verifique novamente o arquivo de entrada.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="207"/>
        <source>File exists</source>
        <comment>warning about overwritting file</comment>
        <translation>O arquivo existe</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="207"/>
        <source>Delta file exists, do you want to overwrite?</source>
        <comment>warning about overwritting file</comment>
        <translation>O arquivo delta já existe, você quer substituí-lo?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="223"/>
        <source>Success</source>
        <comment>information on file written succesfully</comment>
        <translation>O processo foi concluído com sucesso.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="224"/>
        <source>File &apos;%1&apos; was successfuly written.</source>
        <comment>information on file written succesfully</comment>
        <translation>O arquivo ‘%1’ foi gravado com sucesso.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="226"/>
        <source>Took %1 to create the patch.</source>
        <comment>elasped time, leave %1 untranslated</comment>
        <translation>Demorou %1 para criar o arquivo de correção (patch).</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="228"/>
        <source>Error: Could not write the file.</source>
        <comment>information that file was not written succsessfully</comment>
        <translation>Ocorreu um Erro: Não foi possível gravar o arquivo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="284"/>
        <source>Cancel</source>
        <comment>stop an action in progress</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="320"/>
        <source>%1 elapsed</source>
        <comment>elasped time, leave %1 untranslated</comment>
        <translation>%1 decorrido</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="44"/>
        <source>GUI for xdelta3 application.</source>
        <comment>short description for --help and desktop file</comment>
        <translation>É uma interface gráfica para aplicativo ‘Xdelta3’.
O ‘Xdelta3’ é um conjunto de ferramentas projetadas para calcular as alterações entre os arquivos binários. Estas alterações (ou arquivos delta) são semelhantes à ‘diferença’ da saída do programa, pois podem ser utilizadas para armazenar e transmitir apenas as alterações entre arquivos. Os ‘arquivos delta’ que são gerenciados pelo ‘Xdelta3’ são armazenados no formato RFC3284 (VCDIFF).</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="44"/>
        <source>App for generating a binary difference between two files in the form of delta encoding</source>
        <comment>extra description for --help</comment>
        <translation>É um aplicativo que permite gerar uma diferença binária entre dois arquivos na forma de codificação delta</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="48"/>
        <source>file</source>
        <translation>arquivo</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="48"/>
        <source>Name of the delta file</source>
        <translation>Nome do arquivo delta</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="48"/>
        <source>[file]</source>
        <translation>[arquivo]</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>You must run this program as normal user.</source>
        <comment>warning about running application as root</comment>
        <translation>Você tem que executar este programa como um usuário normal.</translation>
    </message>
</context>
</TS>

==> xdelta3-gui_24.3.tar.xz: BUILD/translations/xdelta3-gui_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="27"/>
        <location filename="../mainwindow.ui" line="39"/>
        <source>Create delta</source>
        <extracomment>meaning to create a delta file that bridges between the source and target file
----------
start process</extracomment>
        <translation>Criar um arquivo delta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="30"/>
        <source>Create a binary difference between two files</source>
        <extracomment>meaning to create a delta file that bridges between the source and target file</extracomment>
        <translation>Criar uma diferença binária entre dois arquivos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="49"/>
        <source>Options</source>
        <extracomment>program options</extracomment>
        <translation>Opções</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="95"/>
        <source>Higher number = better compression ratio, but takes more time to finish</source>
        <translation>O número maior corresponde a melhor taxa de compactação, contudo, demora mais para terminar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="98"/>
        <source>Compression level</source>
        <extracomment>level of compression the delta file will use</extracomment>
        <translation>Nível de compressão</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="118"/>
        <source>More compression using various compression algorithms</source>
        <translation>Mais compactação utilizando vários tipos de algoritmos de compactação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="121"/>
        <source>Secondary compression</source>
        <extracomment>an extra layer of compression</extracomment>
        <translation>Compressão secundária</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="131"/>
        <location filename="../mainwindow.ui" line="241"/>
        <source>File selection</source>
        <extracomment>area for selecting input and output files</extracomment>
        <translation>Selecionar o arquivo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="143"/>
        <source>select target (new) file</source>
        <extracomment>select the new file from which to create a delta between it and the source.</extracomment>
        <translation>selecionar o novo arquivo de destino</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <source>Target file</source>
        <translation>Arquivo de destino</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="167"/>
        <source>Source file</source>
        <translation>Arquivo de origem</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="174"/>
        <source>Delta file name</source>
        <translation>Nome do arquivo delta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <source>Select source file...</source>
        <extracomment>starts a file chooser to select a file</extracomment>
        <translation>Selecionar o arquivo de origem...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="194"/>
        <source>select source (old) file</source>
        <extracomment>select the original or source file</extracomment>
        <translation>selecionar o arquivo antigo de origem</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="201"/>
        <source>Select target file...</source>
        <extracomment>starts a file chooser to select a file</extracomment>
        <translation>Selecionar o destino do arquivo...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="208"/>
        <source>Change location...</source>
        <extracomment>starts a file chooser to select destination for output delta file</extracomment>
        <translation>Alterar a localização...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="232"/>
        <location filename="../mainwindow.ui" line="332"/>
        <source>Apply delta</source>
        <extracomment>meaning to apply a delta file to a input file to create a new output file
----------
start the process</extracomment>
        <translation>Aplicar o delta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="235"/>
        <source>Create a new file applying a delta (difference) file to an original file</source>
        <extracomment>meaning to apply a delta file to a input file to create a new output file</extracomment>
        <translation>Criar um novo arquivo a partir de um arquivo delta (da diferença ou da variação) de um arquivo original</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="247"/>
        <source>Input file</source>
        <extracomment>a file to start with as the source or input</extracomment>
        <translation>Arquivo de entrada</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="254"/>
        <source>select input file</source>
        <extracomment>select the input or older file</extracomment>
        <translation>selecionar o arquivo de entrada</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="261"/>
        <source>Select input file...</source>
        <extracomment>starts a file chooser to select a file</extracomment>
        <translation>Selecionar o arquivo de entrada...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="268"/>
        <source>Delta file</source>
        <extracomment>the delta or diff file between the input and the output</extracomment>
        <translation>Arquivo delta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="275"/>
        <source>select delta</source>
        <extracomment>select the delta or patch file</extracomment>
        <translation>selecionar o arquivo delta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="282"/>
        <source>Select delta...</source>
        <extracomment>starts a file chooser to select a file</extracomment>
        <translation>Selecionar o arquivo delta...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <source>Output file</source>
        <extracomment>the final patched output file</extracomment>
        <translation>Arquivo de saída</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="299"/>
        <source>use default, or set up a custom name</source>
        <extracomment>create the new file name</extracomment>
        <translation>utilizar o nome padrão ou definir um nome personalizado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="306"/>
        <source>Change location..</source>
        <extracomment>starts a file chooser to select destination for output file</extracomment>
        <translation>Alterar a localização...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="100"/>
        <source>ISO Files (*.iso);;All Files (*)</source>
        <comment>kinds of files to choose</comment>
        <translation>Arquivos ISO (*.iso);; Todos os Formatos de Arquivos (*)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="101"/>
        <source>ISO Files (*.xdelta3);;All Files (*)</source>
        <comment>kinds of files to choose</comment>
        <translation>Arquivos ISO (*.xdelta3);; Todos os Formatos de Arquivos (*)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="104"/>
        <source>Select file</source>
        <comment>choose a file</comment>
        <translation>Selecionar o arquivo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="123"/>
        <source>Select directory to place the file in</source>
        <comment>select a target directory</comment>
        <translation>Selecionar o diretório para armazenar o arquivo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="135"/>
        <source>Path not found</source>
        <comment>warning about not finding the target directory</comment>
        <translation>O caminho não foi encontrado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="136"/>
        <source>Please select directory again.</source>
        <comment>message to try again</comment>
        <translation>Por favor, selecione novamente o diretório.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="145"/>
        <location filename="../mainwindow.cpp" line="183"/>
        <location filename="../mainwindow.cpp" line="196"/>
        <location filename="../mainwindow.cpp" line="251"/>
        <source>Error</source>
        <translation>Ocorreu um erro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="145"/>
        <source>Please enter a name for the output file.</source>
        <translation>Por favor, insira um nome para o arquivo de saída.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="157"/>
        <source>File exists</source>
        <translation>O arquivo existe</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="158"/>
        <source>Output file exists, do you want to overwrite?</source>
        <comment>warning about overwritting an existing file</comment>
        <translation>O arquivo de saída já existe, você quer substituí-lo?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="175"/>
        <source>Success</source>
        <comment>information that file was successfully written</comment>
        <translation>O processo foi concluído com sucesso.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="176"/>
        <source>File was successfuly written to &apos;%1&apos; directory.</source>
        <comment>information that file was successfully written</comment>
        <translation>O arquivo foi gravado com sucesso no diretório ‘%1’.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="179"/>
        <source>Took %1 to patch the file.</source>
        <comment>elapsed time, leave %1 untranslated</comment>
        <translation>Demorou %1 para corrigir o arquivo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="184"/>
        <source>Error: Could not write the file.</source>
        <comment>information that there was an error creating the file</comment>
        <translation>Ocorreu um Erro: Não foi possível gravar o arquivo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="197"/>
        <source>Please enter a name for the delta file.</source>
        <comment>name of delta file being created</comment>
        <translation>Por favor, insira um nome para o arquivo delta.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="211"/>
        <source>File not found</source>
        <comment>warning about file not found</comment>
        <translation>O arquivo não foi encontrado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="212"/>
        <source>File &apos;%1&apos; found or not a file, please double-check the input.</source>
        <comment>warning about file not found</comment>
        <translation>O arquivo ‘%1’ que foi encontrado não é um arquivo. Por favor, verifique novamente o arquivo de entrada.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="226"/>
        <source>File exists</source>
        <comment>warning about overwritting file</comment>
        <translation>O arquivo existe</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="227"/>
        <source>Delta file exists, do you want to overwrite?</source>
        <comment>warning about overwritting file</comment>
        <translation>O arquivo delta já existe, você quer substituí-lo?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="243"/>
        <source>Success</source>
        <comment>information on file written succesfully</comment>
        <translation>O processo foi concluído com sucesso.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="244"/>
        <source>File &apos;%1&apos; was successfuly written.</source>
        <comment>information on file written succesfully</comment>
        <translation>O arquivo ‘%1’ foi gravado com sucesso.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="247"/>
        <source>Took %1 to create the patch.</source>
        <comment>elasped time, leave %1 untranslated</comment>
        <translation>Demorou %1 para criar o arquivo de correção (patch).</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="252"/>
        <source>Error: Could not write the file.</source>
        <comment>information that file was not written succsessfully</comment>
        <translation>Ocorreu um Erro: Não foi possível gravar o arquivo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="309"/>
        <source>Cancel</source>
        <comment>stop an action in progress</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="345"/>
        <source>%1 elapsed</source>
        <comment>elasped time, leave %1 untranslated</comment>
        <translation>%1 decorrido</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="45"/>
        <source>GUI for xdelta3 application.</source>
        <comment>short description for --help and desktop file</comment>
        <translation>O ‘Xdelta3 GUI’ é uma interface gráfica para o aplicativo ‘Xdelta3’ que é um conjunto de ferramentas projetadas para calcular as alterações entre os arquivos binários. Estas alterações (ou arquivos delta) são semelhantes à ‘diferença’ da saída do programa, pois podem ser utilizadas para armazenar e transmitir apenas as alterações entre arquivos. Os ‘arquivos delta’ que são gerenciados pelo ‘Xdelta3’ e são armazenados no formato RFC3284 (VCDIFF).</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="46"/>
        <source>App for generating a binary difference between two files in the form of delta encoding</source>
        <comment>extra description for --help</comment>
        <translation>É um aplicativo que permite gerar uma diferença binária entre dois arquivos na forma de codificação delta</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>file</source>
        <translation>arquivo</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Name of the delta file</source>
        <translation>Nome do arquivo delta</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>[file]</source>
        <translation>[arquivo]</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="79"/>
        <source>You must run this program as normal user.</source>
        <comment>warning about running application as root</comment>
        <translation>Você tem que executar este programa como um usuário normal.</translation>
    </message>
</context>
</TS>
